# [Social Share Kit](http://socialsharekit.com)

Social Share Kit is a library of decent and good looking CSS/JavaScript social sharing icons, buttons and popups.

To get started and see examples, check out <http://socialsharekit.com>!

## Table of contents

- [License](#license)
- [Documentation](#documentation)
- [Browser support](#browser-support)
- [Contributing](#contributing)

## License

* Social Share Kit is licensed under **Creative Commons Attribution-NonCommercial 3.0** license. As long as you do not use the Social Share Kit in a business or money-making venture, it is free for your own personal use.
* More about license: http://socialsharekit.com/#license
* Pricing: http://socialsharekit.com/#pricing

## Documentation

* Documentation: http://socialsharekit.com/
* Support: http://socialsharekit.com/#support
* Follow on Twitter to get latest news: [@socialsharekit](http://twitter.com/socialsharekit)

## Browser support

IE8+, Chrome, Firefox, Safari. JavaScript library is standalone and has no 3rd party requirements.

## Contributing

* Do not edit CSS file directly since they are automatically generated from LESS files with LESSC compiler. Pull requests should contain changes to both .less and .css files. 

* If contributed changes affects documentation/examples page `docs/index.html`, you should add according changes to it too.

* If you are changing JavaScript `dist/js/social-share-kit.js` compression of the file into  `dist/js/social-share-kit.min.js` is welcomed (with [yuicompressor](http://yui.github.io/yuicompressor/)), but not neccessary. 
